@@ -252,13 +252,7 @@ quiz_text <- function(text) {
       text <- format(text)
     }
     # convert markdown
-    md <- markdown::markdownToHTML(
-      text = text,
-      options = c("use_xhtml", "fragment_only", "mathjax"),
-      extensions = markdown::markdownExtensions(),
-      fragment.only = TRUE,
-      encoding = "UTF-8"
-    )
+    md <- markdown::mark_html(text = text, options = "-standalone")
     if (length(str_match_all(md, "</p>", fixed = TRUE)) == 1) {
       # remove leading and trailing paragraph
       md <- sub("^<p>", "", md)
